@@ -1,16 +1,8 @@
-from __future__ import print_function
+from codecs import BOM_UTF16_BE, BOM_UTF16_LE
+from urllib.request import urlopen
+from urllib.parse import urljoin, urlparse
 
 import rply, sys, os
-from codecs import BOM_UTF16_BE, BOM_UTF16_LE
-if sys.version_info[0] < 3:
-    from urllib2 import urlopen as _urlopen
-    from urlparse import urljoin
-    from contextlib import closing
-    def urlopen(f):
-        return closing(_urlopen(f))
-else:
-    from urllib.request import urlopen
-    from urllib.parse import urljoin
 
 KEYWORDS = set([
     'attribute', 'datatypes', 'default', 'div', 'element', 'empty', 'external',
@@ -213,7 +205,7 @@ def component_div(s, p):
 
 @pg.production('component : INCLUDE strlit opt-inherit opt-include-content')
 def component_include(s, p):
-    if ':' in s.path or ':' in p[1].value:  # it's a URL
+    if is_url(s.path) or is_url(p[1].value):  # it's a URL
         url = urljoin(s.path, p[1].value)
     else:
         url = os.path.join(s.path, p[1].value)
@@ -540,7 +532,7 @@ def name_class_group(s, p):
 @pg.production('documentations : DOCUMENTATION documentations')
 def documentations_multi(s, p):
     cur = Node('DOCUMENTATION', None, []) if not p[1] else p[1][0]
-    cur.value.insert(0, p[0].value.lstrip('# '))
+    cur.value.insert(0, p[0].value.lstrip('# ').rstrip('\r'))
     return [cur]
 
 @pg.production('documentations : ')
@@ -678,7 +670,7 @@ class State(object):
         self.fn = fn
         self.path = os.getcwd()
         if fn is not None:
-            self.path = os.path.dirname(os.path.abspath(fn)) if ':' not in fn else fn
+            self.path = os.path.dirname(os.path.abspath(fn)) if not is_url(fn) else fn
         self.lines = src.splitlines()
 
 if sys.version_info[0] < 3:
@@ -686,11 +678,15 @@ if sys.version_info[0] < 3:
 else:
     str_types = str, bytes
 
+def is_url(fn):
+    parse_result = urlparse(fn)
+    return parse_result.scheme in ('http', 'https', 'file')
+
 def parse(src=None, f=None):
     assert src is None or f is None
     if f is not None and isinstance(f, str_types):
         fn = f
-        if ':' in fn:
+        if is_url(fn):
             with urlopen(fn) as f:
                 bytes = f.read()
         else:
